@@ -25,21 +25,20 @@ function autoSaveNoVerify() {
     syncSettings.setValueInt("level", playerModel.level)
     syncSettings.sync()
     analyzeGameModel.autoSave(gameModel)
-    // This will lose the geometry if the user has changed it, maximized the
-    // window and then closed it before returning to windowed state. But better
-    // than overwriting the geometry with the maximized/fullscreen one.
     if (visibility === Window.Windowed) {
         settings.x = x
         settings.y = y
         settings.width = width
         settings.height = height
     }
-    settings.visibility = visibility
 }
 
 function autoSaveNoVerifyAndQuit() {
     autoSaveNoVerify()
-    Qt.quit()
+    if (isAndroid)
+        androidUtils.exit()
+    else
+        Qt.quit()
 }
 
 function cancelRunning(showMessage) {
@@ -94,6 +93,7 @@ function checkComputerMove() {
             else
                 msg += qsTr("Your rating stays at %1.").arg(newRating)
             isRated = false
+            recentFiles.add(gameModel.file, "")
         }
         showInfo(msg)
         return
@@ -109,14 +109,6 @@ function checkComputerMove() {
     genMove()
 }
 
-function checkStoragePermission() {
-    if (! androidUtils.checkPermission("android.permission.WRITE_EXTERNAL_STORAGE")) {
-        showInfo(qsTr("No permission to access storage"))
-        return false
-    }
-    return true
-}
-
 function clearRating() {
     showQuestion(qsTr("Delete all rating information for the current game variant?"),
                  clearRatingNoVerify)
@@ -198,31 +190,36 @@ function deleteAllVarNoVerify() {
     showTemporaryMessage(qsTr("Variations deleted"))
 }
 
+function expirePersistedUriPermissions() {
+    var uris = androidUtils.getPersistedUriPermissions()
+    var len = uris.length
+    for (var i = 0; i < len; ++i)
+        if (! recentFilesContains(uris[i]) && uris[i] !== initialFile
+                && uris[i] !== gameModel.file)
+            androidUtils.releasePersistableUriPermission(uris[i])
+}
+
 function exportAsciiArt(fileUrl) {
-    if (! checkStoragePermission())
-        return
-    var file = getFileFromUrl(fileUrl)
+    var file = isAndroid ? fileUrl : getFileFromUrl(fileUrl)
     if (! gameModel.saveAsciiArt(file))
         showInfo(qsTr("Save failed.") + "\n" + gameModel.getError())
-    else {
-        androidUtils.scanFile(file)
+    else
         showTemporaryMessage(qsTr("File saved"))
-    }
 }
 
 function exportImage(fileUrl) {
-    if (! checkStoragePermission())
-        return
     var board = gameView.getBoard()
     var size = Qt.size(exportImageWidth, exportImageWidth * board.height / board.width)
     if (! board.grabImageTarget.grabToImage(function(result) {
-        var file = getFileFromUrl(fileUrl)
-        if (! result.saveToFile(file))
+        var ok
+        if (isAndroid)
+            ok = androidUtils.saveImage(fileUrl, result.image)
+        else
+            ok = result.saveToFile(getFileFromUrl(fileUrl))
+        if (! ok)
             showInfo(qsTr("Saving image failed or unsupported image format"))
-        else {
-            androidUtils.scanFile(file)
+        else
             showTemporaryMessage(qsTr("Image saved"))
-        }
     }, size))
         showInfo(qsTr("Creating image failed"))
 }
@@ -242,11 +239,10 @@ function findNextComment() {
 }
 
 function findNextCommentContinueFromRoot() {
-    if (gameModel.findNextCommentContinueFromRoot()) {
+    if (gameModel.findNextCommentContinueFromRoot())
         gameView.showComment()
-        return
-    }
-    showInfo(qsTr("No comment found"))
+    else
+        showInfo(qsTr("No comment found"))
 }
 
 function genMove() {
@@ -259,6 +255,8 @@ function genMove() {
 function getFileFromUrl(fileUrl) {
     var file = fileUrl.toString()
     file = file.replace(/^(file:\/{3})/,"/")
+    if (Qt.platform.os == "windows")
+        file = file.replace(/^\/(\w:)/,"$1").replace(/\//g,"\\")
     return decodeURIComponent(file)
 }
 
@@ -293,16 +291,18 @@ function getGameLabel(setupMode, isRated, file, isModified, short) {
                     qsTr("Rated %1").arg(n)
                   : qsTr("Rated Game %1").arg(n)
     else {
-        var pos = Math.max(file.lastIndexOf("/"), file.lastIndexOf("\\"))
-        label = file.substring(pos + 1)
-        if (label.toLowerCase().endsWith(".blksgf"))
-            label = label.substring(0, label.length - ".blksgf".length)
+        if (isAndroid && displayName !== "")
+            label = displayName
+        else {
+            var pos = Math.max(file.lastIndexOf("/"), file.lastIndexOf("\\"))
+            label = file.substring(pos + 1)
+        }
+        label = label.replace("\.blksgf", "")
     }
     return (isModified ? "*" : "") + label
 }
 
-function getPlayerString(variant, player)
-{
+function getPlayerString(variant, player) {
     var isMultiColor = (variant === "classic_2" || variant === "trigon_2"
                         || variant === "nexos_2" || variant === "callisto_2_4"
                         || variant === "gembloq_2_4")
@@ -345,32 +345,6 @@ function getWindowTitle(file, isModified) {
     return qsTr("%1 - Pentobi").arg(name)
 }
 
-function help() {
-    var lang = Qt.locale().name
-    var pos = lang.indexOf("_")
-    if (pos >= 0)
-        lang = lang.substr(0, pos)
-    if (lang !== "de" && lang !== "es")
-        lang = "C"
-    var url
-    if (isAndroid)
-        url = androidUtils.extractHelp(lang)
-    else if (helpDir)
-        url = "file://" + helpDir + "/" + lang + "/pentobi/index.html"
-    else
-        url = "qrc:///qml/help/" + lang + "/pentobi/index.html"
-    if (openHelpExternally) {
-        Qt.openUrlExternally(url)
-        return
-    }
-    if (! helpWindow.item) {
-        helpWindow.source = "HelpWindow.qml"
-        helpWindow.item.startUrl = url
-    }
-    helpWindow.item.show()
-    helpWindow.item.init()
-}
-
 function init() {
     if (gameModel.loadAutoSave()) {
         computerPlays0 =
@@ -387,6 +361,8 @@ function init() {
                                        initComputerColorsOnNewGame)
         analyzeGameModel.loadAutoSave(gameModel)
     }
+    if (isAndroid)
+        expirePersistedUriPermissions(initialFile, gameModel.file)
     playerModel.level = syncSettings.valueInt("level", 1)
     if (isMultiColor()) {
         computerPlays2 = computerPlays0
@@ -396,16 +372,23 @@ function init() {
     if (gameModel.checkFileModifiedOutside())
     {
         showWindow()
-        showQuestion(qsTr("File has been modified by another application. Reload?"), reloadFile)
+        showQuestion(qsTr("File has been modified by another application. Reload?"),
+                     reloadFile)
         return
     }
     if (analyzeGameModel.elements.length > 0)
         gameView.analysisAutoloaded()
     // initialFile is a context property set from command line argument
     if (initialFile) {
-        if (gameModel.isModified)
+        if (! gameModel.isModified) {
+            openFileBlocking(initialFile, displayName )
             showWindow()
-        verify(function() { openFileBlocking(initialFile) })
+        }
+        else {
+            showWindow()
+            verify(function() { openFileBlocking(initialFile, displayName ) })
+        }
+        return
     }
     showWindow()
     if (isRated) {
@@ -493,13 +476,11 @@ function moveUpVar() {
     showVariationInfo()
 }
 
-function newGame()
-{
+function newGame() {
     verify(newGameNoVerify)
 }
 
-function newGameNoVerify()
-{
+function newGameNoVerify() {
     gameModel.newGame()
     gameView.setupMode = false
     gameView.showToPlay()
@@ -519,27 +500,33 @@ function nextPiece() {
 }
 
 function open() {
-    if (! checkStoragePermission())
-        return
     verify(openNoVerify)
 }
 
 function openNoVerify() {
-    openDialog.open()
+    if (isAndroid)
+        androidUtils.openOpenDialog(gameModel.file)
+    else
+        openDialog.open()
 }
 
-function openFile(file) {
-    lengthyCommand.run(function() { openFileBlocking(file) })
+function openFile(file, displayName) {
+    lengthyCommand.run(function() { openFileBlocking(file, displayName) })
 }
 
-function openFileBlocking(file) {
+function openFileBlocking(file, displayName) {
     var oldGameVariant = gameModel.gameVariant
     var oldEnableAnimations = gameView.enableAnimations
     gameView.enableAnimations = false
     if (! gameModel.openFile(file))
         showInfo(qsTr("Open failed.") + "\n" + gameModel.getError())
-    else
+    else {
+        if (isAndroid)
+            displayName = androidUtils.getDisplayName(file)
+        rootWindow.displayName = displayName
+        recentFiles.add(file, displayName)
         setComputerNone()
+    }
     if (gameModel.gameVariant !== oldGameVariant)
         gameView.createPieces()
     gameView.showToPlay()
@@ -554,11 +541,10 @@ function openFileBlocking(file) {
 }
 
 function openFileUrl() {
-    openFile(getFileFromUrl(openDialog.item.fileUrl))
+    openFile(getFileFromUrl(openDialog.item.fileUrl), "")
 }
 
-function openClipboard()
-{
+function openClipboard() {
     verify(openClipboardNoVerify)
 }
 
@@ -581,10 +567,8 @@ function openClipboardNoVerify() {
     })
 }
 
-function openRecentFile(file) {
-    if (! checkStoragePermission())
-        return
-    verify(function() { openFile(file) })
+function openRecentFile(file, displayName) {
+    verify(function() { openFile(file, displayName) })
 }
 
 function pickNamedPiece(name) {
@@ -623,11 +607,12 @@ function quit() {
         return false
     }
     autoSaveNoVerify()
+    if (isAndroid)
+        androidUtils.exit()
     return true
 }
 
-function ratedGame()
-{
+function ratedGame() {
     verify(ratedGameCheckFirstGame)
 }
 
@@ -638,8 +623,7 @@ function ratedGameCheckFirstGame() {
         ratedGameNoVerify()
 }
 
-function ratedGameNoVerify()
-{
+function ratedGameNoVerify() {
     var player = ratingModel.getNextHumanPlayer()
     var level = ratingModel.getNextLevel(playerModel.maxLevel)
     var gameVariant = gameModel.gameVariant
@@ -721,13 +705,20 @@ function rating() {
     ratingDialog.open()
 }
 
+function recentFilesContains(file) {
+    var entries = recentFiles.entries
+    var len = entries.length
+    for (var i = 0; i < len; ++i)
+        if (entries[i].file === file)
+            return true
+    return false
+}
+
 function reloadFile() {
-    openFile(gameModel.file)
+    openFile(gameModel.file, displayName)
 }
 
 function save() {
-    if (! checkStoragePermission())
-        return
     if (gameModel.checkFileModifiedOutside())
         showQuestion(qsTr("File has been modified by another application. Overwrite?"),
                      saveCurrentFile)
@@ -736,22 +727,35 @@ function save() {
 }
 
 function saveAs() {
-    if (! checkStoragePermission())
-        return
-    var dialog = saveDialog.get()
-    dialog.name = gameModel.suggestGameFileName(folder)
-    dialog.open()
+    if (isAndroid) {
+        var file = gameModel.file
+        var name
+        if (ratingModel.getGameNumberOfFile(file) > 0)
+            name = file.substring(file.lastIndexOf("/") + 1)
+        else if (displayName !== "")
+            name = displayName
+        else
+            name = gameModel.suggestGameFileName("")
+        androidUtils.openSaveDialog(file, name)
+    } else {
+        var dialog = saveDialog.get()
+        dialog.name = gameModel.suggestGameFileName(folder)
+        dialog.open()
+    }
 }
 
 function saveCurrentFile() {
-    saveFile(gameModel.file)
+    saveFile(gameModel.file, displayName)
 }
 
-function saveFile(file) {
+function saveFile(file, displayName) {
     if (! gameModel.save(file))
         showInfo(qsTr("Save failed.") + "\n" + gameModel.getError())
-    else
+    else {
+        recentFiles.add(file, displayName)
+        rootWindow.displayName = displayName
         showTemporaryMessage(qsTr("File saved"))
+    }
 }
 
 function setComputerNone() {
@@ -786,14 +790,24 @@ function showVariationInfo() {
 }
 
 function showWindow() {
-    x = settings.x
-    y = settings.y
+    if (isAndroid) {
+        show()
+        return
+    }
     width = settings.width
     height = settings.height
-    switch (settings.visibility) {
-    case Window.Maximized: showMaximized(); break
-    case Window.FullScreen: showFullScreen(); break
-    default: show()
+    x = settings.x
+    y = settings.y
+    show()
+    var maxWidth = rootWindow.Screen.desktopAvailableWidth
+    var maxHeight = rootWindow.Screen.desktopAvailableHeight
+    if (width < minimumWidth || height < minimumHeight || x < 0 || y < 0
+            || x + width >= maxWidth || y + height >= maxHeight)
+    {
+        width = Math.min(maxWidth, 1164)
+        height = Math.min(maxHeight, width * 662 / 1164)
+        x = (rootWindow.Screen.width - width) / 2
+        y = (rootWindow.Screen.height - height) / 2
     }
 }
 
@@ -814,8 +828,7 @@ function undo() {
     gameModel.undo()
 }
 
-function verify(callback)
-{
+function verify(callback) {
     if (gameModel.isModified) {
         showQuestion(qsTr("Discard game?"), callback)
         return
