@@ -195,28 +195,27 @@
     </message>
 </context>
 <context>
-    <name>ExportImageDialog</name>
+    <name>DocbookReader</name>
     <message>
-        <source>Image width:</source>
+        <source>Previous</source>
+        <extracomment>Go to previous page of user manual</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Contents</source>
+        <extracomment>Go to table of contents of user manual</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Next</source>
+        <extracomment>Go to next page of user manual</extracomment>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
-    <name>FileDialog</name>
+    <name>ExportImageDialog</name>
     <message>
-        <source>Overwrite file?</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Open</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Save</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>All files</source>
+        <source>Image width:</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -570,10 +569,6 @@
         <source>Your rating stays at %1.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>No permission to access storage</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Delete all rating information for the current game variant?</source>
         <translation type="unfinished"></translation>
@@ -1009,19 +1004,6 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>MenuItem</name>
-    <message>
-        <source>Ctrl</source>
-        <extracomment>Shortcut modifier key as displayed in menu item text (abbreviate if long)</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Shift</source>
-        <extracomment>Shortcut modifier key as displayed in menu item text (abbreviate if long)</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>MenuRecentFiles</name>
     <message>
@@ -1125,6 +1107,110 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>PentobiFileDialog</name>
+    <message>
+        <source>Overwrite file?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All files</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>PentobiMenuItem</name>
+    <message>
+        <source>Ctrl</source>
+        <extracomment>Shortcut modifier key as displayed in menu item text (abbreviate if long)</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Shift</source>
+        <extracomment>Shortcut modifier key as displayed in menu item text (abbreviate if long)</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>PentobiToolBar</name>
+    <message>
+        <source>Start a new game</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start a rated game</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set the colors played by the computer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Make the computer continue to play the current color</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Make the computer play the current color</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Go to beginning of game</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Go ten moves backward</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Go one move backward</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Go one move forward</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Go ten moves forward</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Go to end of moves</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Go to previous variation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Go to next variation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Abort game analysis</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Abort computer move</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Undo move</source>
+        <extracomment>Tooltip for Undo button</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open menu</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RatingDialog</name>
     <message>
@@ -1294,78 +1380,6 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>ToolBar</name>
-    <message>
-        <source>Start a new game</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Start a rated game</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Set the colors played by the computer</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Make the computer continue to play the current color</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Make the computer play the current color</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Go to beginning of game</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Go ten moves backward</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Go one move backward</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Go one move forward</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Go ten moves forward</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Go to end of moves</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Go to previous variation</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Go to next variation</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Abort game analysis</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Abort computer move</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Undo move</source>
-        <extracomment>Tooltip for Undo button</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Open menu</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>main</name>
     <message>
