@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
 <context>
     <name>AboutDialog</name>
     <message>
@@ -192,6 +192,24 @@
         <translation>Nivel %1</translation>
     </message>
 </context>
+<context>
+    <name>DocbookReader</name>
+    <message>
+        <source>Previous</source>
+        <extracomment>Go to previous page of user manual</extracomment>
+        <translation>Anterior</translation>
+    </message>
+    <message>
+        <source>Contents</source>
+        <extracomment>Go to table of contents of user manual</extracomment>
+        <translation>Inicio</translation>
+    </message>
+    <message>
+        <source>Next</source>
+        <extracomment>Go to next page of user manual</extracomment>
+        <translation>Siguiente</translation>
+    </message>
+</context>
 <context>
     <name>ExportImageDialog</name>
     <message>
@@ -199,25 +217,6 @@
         <translation>Ancho de la imagen:</translation>
     </message>
 </context>
-<context>
-    <name>FileDialog</name>
-    <message>
-        <source>Overwrite file?</source>
-        <translation>¿Sobrescribir archivo?</translation>
-    </message>
-    <message>
-        <source>Open</source>
-        <translation>Abrir</translation>
-    </message>
-    <message>
-        <source>Save</source>
-        <translation>Guardar</translation>
-    </message>
-    <message>
-        <source>All files</source>
-        <translation>Todos los archivos</translation>
-    </message>
-</context>
 <context>
     <name>GameInfoDialog</name>
     <message>
@@ -568,10 +567,6 @@
         <source>Your rating stays at %1.</source>
         <translation>Su nivel sigue siendo %1.</translation>
     </message>
-    <message>
-        <source>No permission to access storage</source>
-        <translation>Sin permiso para acceder al almacenamiento</translation>
-    </message>
     <message>
         <source>Delete all rating information for the current game variant?</source>
         <translation>¿Desactivar la selección de nivel para la variante de juego actual?</translation>
@@ -888,7 +883,7 @@
     </message>
     <message>
         <source>Press back again to exit</source>
-        <translation type="unfinished"/>
+        <translation>Vuelva a presionar atrás para salir</translation>
     </message>
 </context>
 <context>
@@ -1007,19 +1002,6 @@
         <translation>Informe de errores</translation>
     </message>
 </context>
-<context>
-    <name>MenuItem</name>
-    <message>
-        <source>Ctrl</source>
-        <extracomment>Shortcut modifier key as displayed in menu item text (abbreviate if long)</extracomment>
-        <translation>Ctrl</translation>
-    </message>
-    <message>
-        <source>Shift</source>
-        <extracomment>Shortcut modifier key as displayed in menu item text (abbreviate if long)</extracomment>
-        <translation>Mayús</translation>
-    </message>
-</context>
 <context>
     <name>MenuRecentFiles</name>
     <message>
@@ -1123,6 +1105,110 @@
         <translation>Partidas de Blokus</translation>
     </message>
 </context>
+<context>
+    <name>PentobiFileDialog</name>
+    <message>
+        <source>Overwrite file?</source>
+        <translation>¿Sobrescribir archivo?</translation>
+    </message>
+    <message>
+        <source>Open</source>
+        <translation>Abrir</translation>
+    </message>
+    <message>
+        <source>Save</source>
+        <translation>Guardar</translation>
+    </message>
+    <message>
+        <source>All files</source>
+        <translation>Todos los archivos</translation>
+    </message>
+</context>
+<context>
+    <name>PentobiMenuItem</name>
+    <message>
+        <source>Ctrl</source>
+        <extracomment>Shortcut modifier key as displayed in menu item text (abbreviate if long)</extracomment>
+        <translation>Ctrl</translation>
+    </message>
+    <message>
+        <source>Shift</source>
+        <extracomment>Shortcut modifier key as displayed in menu item text (abbreviate if long)</extracomment>
+        <translation>Mayús</translation>
+    </message>
+</context>
+<context>
+    <name>PentobiToolBar</name>
+    <message>
+        <source>Start a new game</source>
+        <translation>Comenzar una partida nueva</translation>
+    </message>
+    <message>
+        <source>Start a rated game</source>
+        <translation>Comenzar una partida con selección de nivel</translation>
+    </message>
+    <message>
+        <source>Set the colors played by the computer</source>
+        <translation>Elija los colores con los que jugará la máquina</translation>
+    </message>
+    <message>
+        <source>Make the computer continue to play the current color</source>
+        <translation>Haga que la máquina siga jugando con el color actual</translation>
+    </message>
+    <message>
+        <source>Make the computer play the current color</source>
+        <translation>Haga que la máquina juegue con el color actual</translation>
+    </message>
+    <message>
+        <source>Go to beginning of game</source>
+        <translation>Ir al inicio de la partida</translation>
+    </message>
+    <message>
+        <source>Go ten moves backward</source>
+        <translation>Retroceder diez movimientos</translation>
+    </message>
+    <message>
+        <source>Go one move backward</source>
+        <translation>Retroceder un movimiento</translation>
+    </message>
+    <message>
+        <source>Go one move forward</source>
+        <translation>Avanzar un movimiento</translation>
+    </message>
+    <message>
+        <source>Go ten moves forward</source>
+        <translation>Avanzar diez movimientos</translation>
+    </message>
+    <message>
+        <source>Go to end of moves</source>
+        <translation>Ir al final de los movimientos</translation>
+    </message>
+    <message>
+        <source>Go to previous variation</source>
+        <translation>Ir a la variación anterior</translation>
+    </message>
+    <message>
+        <source>Go to next variation</source>
+        <translation>Ir a la siguiente variación</translation>
+    </message>
+    <message>
+        <source>Abort game analysis</source>
+        <translation>Anular análisis de la partida</translation>
+    </message>
+    <message>
+        <source>Abort computer move</source>
+        <translation>Anular movimiento de la máquina</translation>
+    </message>
+    <message>
+        <source>Undo move</source>
+        <extracomment>Tooltip for Undo button</extracomment>
+        <translation>Deshacer movimiento</translation>
+    </message>
+    <message>
+        <source>Open menu</source>
+        <translation>Abrir menú</translation>
+    </message>
+</context>
 <context>
     <name>RatingDialog</name>
     <message>
@@ -1292,78 +1378,6 @@
         <translation>Empate</translation>
     </message>
 </context>
-<context>
-    <name>ToolBar</name>
-    <message>
-        <source>Start a new game</source>
-        <translation>Comenzar una partida nueva</translation>
-    </message>
-    <message>
-        <source>Start a rated game</source>
-        <translation>Comenzar una partida con selección de nivel</translation>
-    </message>
-    <message>
-        <source>Set the colors played by the computer</source>
-        <translation>Elija los colores con los que jugará la máquina</translation>
-    </message>
-    <message>
-        <source>Make the computer continue to play the current color</source>
-        <translation>Haga que la máquina siga jugando con el color actual</translation>
-    </message>
-    <message>
-        <source>Make the computer play the current color</source>
-        <translation>Haga que la máquina juegue con el color actual</translation>
-    </message>
-    <message>
-        <source>Go to beginning of game</source>
-        <translation>Ir al inicio de la partida</translation>
-    </message>
-    <message>
-        <source>Go ten moves backward</source>
-        <translation>Retroceder diez movimientos</translation>
-    </message>
-    <message>
-        <source>Go one move backward</source>
-        <translation>Retroceder un movimiento</translation>
-    </message>
-    <message>
-        <source>Go one move forward</source>
-        <translation>Avanzar un movimiento</translation>
-    </message>
-    <message>
-        <source>Go ten moves forward</source>
-        <translation>Avanzar diez movimientos</translation>
-    </message>
-    <message>
-        <source>Go to end of moves</source>
-        <translation>Ir al final de los movimientos</translation>
-    </message>
-    <message>
-        <source>Go to previous variation</source>
-        <translation>Ir a la variación anterior</translation>
-    </message>
-    <message>
-        <source>Go to next variation</source>
-        <translation>Ir a la siguiente variación</translation>
-    </message>
-    <message>
-        <source>Abort game analysis</source>
-        <translation>Anular análisis de la partida</translation>
-    </message>
-    <message>
-        <source>Abort computer move</source>
-        <translation>Anular movimiento de la máquina</translation>
-    </message>
-    <message>
-        <source>Undo move</source>
-        <extracomment>Tooltip for Undo button</extracomment>
-        <translation>Deshacer movimiento</translation>
-    </message>
-    <message>
-        <source>Open menu</source>
-        <translation>Abrir menú</translation>
-    </message>
-</context>
 <context>
     <name>main</name>
     <message>
