@@ -20,6 +20,21 @@ using namespace std;
 
 //-----------------------------------------------------------------------------
 
+namespace {
+
+QString getTranslationsPath()
+{
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    return QLibraryInfo::location(QLibraryInfo::TranslationsPath);
+#else
+    return QLibraryInfo::path(QLibraryInfo::TranslationsPath);
+#endif
+}
+
+} // namespace
+
+//-----------------------------------------------------------------------------
+
 int main(int argc, char* argv[])
 {
     libboardgame_base::LogInitializer log_initializer;
@@ -27,14 +42,13 @@ int main(int argc, char* argv[])
     QCoreApplication app(argc, argv);
 
     QTranslator qtTranslator;
-    qtTranslator.load(
-                "qt_" + QLocale::system().name(),
-                QLibraryInfo::location(QLibraryInfo::TranslationsPath));
-    QCoreApplication::installTranslator(&qtTranslator);
+    if (qtTranslator.load("qt_" + QLocale::system().name(),
+                          getTranslationsPath()))
+        QCoreApplication::installTranslator(&qtTranslator);
 
     QTranslator translator;
-    translator.load(":i18n/" + QLocale::system().name());
-    QCoreApplication::installTranslator(&translator);
+    if (translator.load(":i18n/" + QLocale::system().name()))
+        QCoreApplication::installTranslator(&translator);
 
     try
     {
